@@ -14,11 +14,12 @@
 
 import mock
 
-from networking_calico.agent.linux.interface import RoutedInterfaceDriver
 from neutron.agent.common import config
 from neutron.agent.linux import interface
 from neutron.tests import base
-from oslo_config import cfg
+
+from networking_calico.agent.linux.interface import RoutedInterfaceDriver
+from networking_calico.compat import cfg
 
 
 class _TestInterfaceDriverMixin(object):
